<?php
/* $Id: image_extractor.php,v 1.2 2013/05/14 15:02:30 rp Exp $
 *
 * PDF image extractor based on PDFlib TET
 */


/* global option list */
$globaloptlist = "searchpath={{../data} {../../data} }";

/* document-specific option list */
$docoptlist = "";

/* page-specific option list */
$pageoptlist = "skipengines={text}";

/* here you can insert basic image extract options (more below) */
$baseimageoptlist = "";

$pageno = 0;

try {
    $infilename = "FontReporter.pdf";
    $outfilebase = $infilename;

    $tet = new TET();

    $tet->set_option($globaloptlist);

    $doc = $tet->open_document($infilename, $docoptlist);

    if ($doc == -1) {
	die("Error ". $tet->get_errnum() . " in " . $tet->get_apiname()
	    . "(): " . $tet->get_errmsg() . "\n");
    }

    /* Get number of pages in the document */
    $n_pages = $tet->pcos_get_number($doc, "length:pages");

    /* loop over pages in the document */
    for ($pageno = 1; $pageno <= $n_pages; ++$pageno) {

	$page = $tet->open_page($doc, $pageno, $pageoptlist);

	if ($page == -1) {
	    print("Error ". $tet->get_errnum() ." in ". $tet->get_apiname()
		. "(): " . $tet->get_errmsg() . "\n");
	    next;                        /* try next page */
	}

	/* Retrieve all images on the page */
	while ($ti = $tet->get_image_info($page) ) {
	   /* Report image geometry */
	    print("page " . $pageno . ": " .
		(int) $ti->width . "x" .
		(int) $ti->height . "pt, alpha=" .
		$ti->alpha . ", beta=" .
		$ti->beta . "\n");

	    /* Retrieve additional image properties with pCOS */
	    print("   id=" . $ti->imageid . ", " .
		(int) $tet->pcos_get_number($doc, "images[" . $ti->imageid . "]/Width"). "x" .
		(int) $tet->pcos_get_number($doc, "images[" . $ti->imageid . "]/Height") . " pixel, ");
	    $cs =  $tet->pcos_get_number($doc, "images[". $ti->imageid .
		"]/colorspaceid");

	    if ($cs != -1){
	    print( (int) $tet->pcos_get_number($doc, "colorspaces[" . $cs . "]/components") . "x" .
		(int) $tet->pcos_get_number($doc, "images[" . $ti->imageid . "]/bpc") . " bit " .
		$tet->pcos_get_string($doc, "colorspaces[" . $cs . "]/name") . "\n");
	    }
	    else
	    {
		/* cs==-1 may happen for some JPEG 2000 images. bpc,
		 * colorspace name and number of components are not
		 * available in this case.
		 */

		print("JPEG2000\n");
	    }
	    /*
	     * Fetch image data and write it to a disk file. The
	     * output filename is generated from the input filename,
	     * page number and image ID.
	     */
	    $imageoptlist = $baseimageoptlist . " filename {" .
		$outfilebase . "_p" . $pageno . "_I" . $ti->imageid . "}";
	    if ($tet->write_image_file($doc, $ti->imageid, $imageoptlist) == 0){
		print("Error " . $tet->get_errnum() . " in " .
		    $tet->get_apiname() . "(): " . $tet->get_errmsg());
	    }

	}


	if ($tet->get_errnum() != 0) {
	    print("Error ". $tet->get_errnum() . " in " . 
		    $tet->get_apiname() . "(): on page $pageno" 
		    . $tet->get_errmsg() . "\n");
	}

	$tet->close_page($page);
    }

    $tet->close_document($doc);
}
catch (TETException $e) {
    if ($pageno == 0) {
	die("TET exception occurred in image_extractor sample:\n" .
	    "[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
	    $e->get_errmsg() . "\n");
    } else {
	die("TET exception occurred in image_extractor sample:\n" .
	    "[" . $e->get_errnum() . "] " . $e->get_apiname() .
	    "on page $pageno: " .  $e->get_errmsg() . "\n");
    }
}
catch (Exception $e) {
    die($e);
}

$tet = 0;
?>
